embassy-nrf

Crates

git

Versions

nrf54lm20-app-s

Flavors

Ghwcfg3

Struct Ghwcfg3 

#[repr(transparent)]
pub struct Ghwcfg3(pub u32);
User Hardware Configuration 3 Register

Tuple Fields

0: u32

Implementations

Source

impl Ghwcfg3

pub const fn xfersizewidth(&self) -> Xfersizewidth

Width of Transfer Size Counters (XferSizeWidth)

pub const fn set_xfersizewidth(&mut self, val: Xfersizewidth)

Width of Transfer Size Counters (XferSizeWidth)

pub const fn pktsizewidth(&self) -> Pktsizewidth

Width of Packet Size Counters (PktSizeWidth)

pub const fn set_pktsizewidth(&mut self, val: Pktsizewidth)

Width of Packet Size Counters (PktSizeWidth)

pub const fn otgen(&self) -> bool

OTG Function Enabled (OtgEn)

pub const fn set_otgen(&mut self, val: bool)

OTG Function Enabled (OtgEn)

pub const fn i2cintsel(&self) -> bool

I2C Selection (I2CIntSel)

pub const fn set_i2cintsel(&mut self, val: bool)

I2C Selection (I2CIntSel)

pub const fn vndctlsupt(&self) -> bool

Vendor Control Interface Support (VndctlSupt)

pub const fn set_vndctlsupt(&mut self, val: bool)

Vendor Control Interface Support (VndctlSupt)

pub const fn optfeature(&self) -> bool

Optional Features Removed (OptFeature)

pub const fn set_optfeature(&mut self, val: bool)

Optional Features Removed (OptFeature)

pub const fn rsttype(&self) -> Rsttype

Reset Style for Clocked always Blocks in RTL (RstType)

pub const fn set_rsttype(&mut self, val: Rsttype)

Reset Style for Clocked always Blocks in RTL (RstType)

pub const fn adpsupport(&self) -> bool

This bit indicates whether ADP logic is present within or external to the controller

pub const fn set_adpsupport(&mut self, val: bool)

This bit indicates whether ADP logic is present within or external to the controller

pub const fn hsicmode(&self) -> bool

HSIC mode specified for Mode of Operation

pub const fn set_hsicmode(&mut self, val: bool)

HSIC mode specified for Mode of Operation

pub const fn bcsupport(&self) -> bool

This bit indicates the controller support for Battery Charger.

pub const fn set_bcsupport(&mut self, val: bool)

This bit indicates the controller support for Battery Charger.

pub const fn lpmmode(&self) -> bool

LPM mode specified for Mode of Operation.

pub const fn set_lpmmode(&mut self, val: bool)

LPM mode specified for Mode of Operation.

pub const fn dfifodepth(&self) -> u16

DFIFO Depth (DfifoDepth - EP_LOC_CNT)

pub const fn set_dfifodepth(&mut self, val: u16)

DFIFO Depth (DfifoDepth - EP_LOC_CNT)