embassy-nrf

Crates

git

Versions

nrf54lm20-app-s

Flavors

Gpwrdn

Struct Gpwrdn 

#[repr(transparent)]
pub struct Gpwrdn(pub u32);
Global Power Down Register.

Tuple Fields

0: u32

Implementations



impl Gpwrdn

pub const fn pmuintsel(&self) -> bool

PMU Interrupt Select (PMUIntSel).

pub const fn set_pmuintsel(&mut self, val: bool)

PMU Interrupt Select (PMUIntSel).

pub const fn pmuactv(&self) -> bool

PMU Active (PMUActv).

pub const fn set_pmuactv(&mut self, val: bool)

PMU Active (PMUActv).

pub const fn restore(&self) -> bool

Restore.

pub const fn set_restore(&mut self, val: bool)

Restore.

pub const fn pwrdnclmp(&self) -> bool

Power Down Clamp (PwrDnClmp).

pub const fn set_pwrdnclmp(&mut self, val: bool)

Power Down Clamp (PwrDnClmp).

pub const fn pwrdnrstn(&self) -> bool

Power Down ResetN (PwrDnRst_n).

pub const fn set_pwrdnrstn(&mut self, val: bool)

Power Down ResetN (PwrDnRst_n).

pub const fn pwrdnswtch(&self) -> Pwrdnswtch

Power Down Switch (PwrDnSwtch).

pub const fn set_pwrdnswtch(&mut self, val: Pwrdnswtch)

Power Down Switch (PwrDnSwtch).

pub const fn disablevbus(&self) -> bool

DisableVBUS.

pub const fn set_disablevbus(&mut self, val: bool)

DisableVBUS.

pub const fn lnstschng(&self) -> bool

Line State Change (LnStsChng).

pub const fn set_lnstschng(&mut self, val: bool)

Line State Change (LnStsChng).

pub const fn linestagechangemsk(&self) -> bool

LineStageChangeMsk.

pub const fn set_linestagechangemsk(&mut self, val: bool)

LineStageChangeMsk.

pub const fn resetdetected(&self) -> bool

ResetDetected.

pub const fn set_resetdetected(&mut self, val: bool)

ResetDetected.

pub const fn resetdetmsk(&self) -> bool

ResetDetMsk.

pub const fn set_resetdetmsk(&mut self, val: bool)

ResetDetMsk.

pub const fn disconnectdetect(&self) -> bool

DisconnectDetect.

pub const fn set_disconnectdetect(&mut self, val: bool)

DisconnectDetect.

pub const fn disconnectdetectmsk(&self) -> bool

DisconnectDetectMsk.

pub const fn set_disconnectdetectmsk(&mut self, val: bool)

DisconnectDetectMsk.

pub const fn connectdet(&self) -> bool

ConnectDet.

pub const fn set_connectdet(&mut self, val: bool)

ConnectDet.

pub const fn conndetmsk(&self) -> bool

ConnDetMsk.

pub const fn set_conndetmsk(&mut self, val: bool)

ConnDetMsk.

pub const fn srpdetect(&self) -> bool

SRPDetect.

pub const fn set_srpdetect(&mut self, val: bool)

SRPDetect.

pub const fn srpdetectmsk(&self) -> bool

SRPDetectMsk.

pub const fn set_srpdetectmsk(&mut self, val: bool)

SRPDetectMsk.

pub const fn stschngint(&self) -> bool

Status Change Interrupt (StsChngInt).

pub const fn set_stschngint(&mut self, val: bool)

Status Change Interrupt (StsChngInt).

pub const fn stschngintmsk(&self) -> bool

StsChngIntMsk.

pub const fn set_stschngintmsk(&mut self, val: bool)

StsChngIntMsk.

pub const fn linestate(&self) -> Linestate

LineState.

pub const fn set_linestate(&mut self, val: Linestate)

LineState.

pub const fn iddig(&self) -> bool

This bit indicates the status of the signal IDDIG. The application must read this bit after receiving GPWRDN.StsChngInt and decode based on the previous value stored by the application.

pub const fn set_iddig(&mut self, val: bool)

This bit indicates the status of the signal IDDIG. The application must read this bit after receiving GPWRDN.StsChngInt and decode based on the previous value stored by the application.

pub const fn bsessvld(&self) -> bool

B Session Valid (BSessVld).

pub const fn set_bsessvld(&mut self, val: bool)

B Session Valid (BSessVld).

pub const fn multvalidbc(&self) -> GpwrdnMultvalidbc

MultValIdBC.

pub const fn set_multvalidbc(&mut self, val: GpwrdnMultvalidbc)

MultValIdBC.